<?php defined('BASEPATH') OR exit('No direct script access allowed'); ?>

ERROR - 2024-11-01 01:57:03 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
